@@ -5,25 +5,25 @@ The full license is in the file LICENSE, distributed with this software.
 
 Copyright (C) Jun Zhu. All rights reserved.
 """
-from .scan import *
-from .data_processing import *
+from .experiment import *
 from .io import *
-from .ml import *
 from .optimization import *
 from .optimizers import *
+from .proc import *
+from .scan import *
 from .simulation import *
 from .visualization import *
 
 __all__ = []
 
-__all__ += data_processing.__all__
+__all__ += experiment.__all__
 __all__ += io.__all__
-__all__ += ml.__all__
 __all__ += optimization.__all__
 __all__ += optimizers.__all__
+__all__ += proc.__all__
 __all__ += scan.__all__
 __all__ += simulation.__all__
 __all__ += visualization.__all__
 
 
-__version__ = "0.3.1"
+__version__ = "0.4.0"
